geowatch.utils.lightning\_ext.argparse\_ext module
==================================================

.. automodule:: geowatch.utils.lightning_ext.argparse_ext
   :members:
   :undoc-members:
   :show-inheritance:
